function Aloc = STIMA_LaplRobin_LFE(Vertices, flag, BdEdges, EHandle, varargin)

    % Preallocate memory
    Aloc = zeros(3,3);

    % Analytic computation of matrix entries using barycentric 
    % coordinates
    a = norm(Vertices(3,:)-Vertices(2,:)); 
    b = norm(Vertices(3,:)-Vertices(1,:));
    c = norm(Vertices(2,:)-Vertices(1,:));
    s = (a+b+c)/2;
    r = sqrt((s-a)*(s-b)*(s-c)/s);
    cot_1 = cot(2*atan(r/(s-a)));
    cot_2 = cot(2*atan(r/(s-b)));
    cot_3 = cot(2*atan(r/(s-c)));
  
    Aloc(1,1) = 1/2*(cot_3+cot_2);
    Aloc(1,2) = 1/2*(-cot_3);
    Aloc(1,3) = 1/2*(-cot_2);
    Aloc(2,2) = 1/2*(cot_3+cot_1);
    Aloc(2,3) = 1/2*(-cot_1);
    Aloc(3,3) = 1/2*(cot_2+cot_1);
  
    % Update lower triangular part
    Aloc(2,1) = Aloc(1,2);
    Aloc(3,1) = Aloc(1,3);
    Aloc(3,2) = Aloc(2,3);

    % Boundary
    for i = BdEdges'
        verts = setdiff(1:3, i);
        h = norm(Vertices(verts(1),:) - Vertices(verts(2),:));
        gamma1 = EHandle(Vertices(verts(1),:));
        gamma2 = EHandle(Vertices(verts(2),:));
        Aloc(verts(1),verts(1)) =... 
                Aloc(verts(1),verts(1)) + h/2 * gamma1;
        Aloc(verts(2),verts(2)) =... 
                Aloc(verts(2),verts(2)) + h/2 * gamma2;
    end

end
