function varargout = assemMatLapRobin_LFE(Mesh, gammaHandle)

    % Initialize constants
    nElements = size(Mesh.Elements,1);
  
    % Preallocate memory
    I = zeros(9*nElements,1);
    J = zeros(9*nElements,1);
    A = zeros(9*nElements,1);
  
    % Check for element flags
    if(isfield(Mesh,'ElemFlag')),
        flags = Mesh.ElemFlag; 
    else
        flags = zeros(nElements,1);
    end

    % Assemble element contributions
    loc = 1:9;
    for i = 1:nElements

        % Extract vertices of current element
        idx = Mesh.Elements(i,:);
        Vertices = Mesh.Coordinates(idx,:);

        % Extract boundary data
        % BdEdges should contain 1 if the edge opposite of
        % vertex 1 is a boundary edge. If BdEdges is empty
        % then the element is in the interior.
        BdEdges = [];
        if Mesh.BdFlags(Mesh.Vert2Edge(idx(2),idx(3))) < 0
            BdEdges = [BdEdges; 1];
        end
        if Mesh.BdFlags(Mesh.Vert2Edge(idx(1),idx(3))) < 0
            BdEdges = [BdEdges; 2];
        end
        if Mesh.BdFlags(Mesh.Vert2Edge(idx(1),idx(2))) < 0
            BdEdges = [BdEdges; 3];
        end

        % Compute element contributions
        Aloc = STIMA_LaplRobin_LFE(Vertices, flags(i),...
                                   BdEdges, gammaHandle);

        % Add contributions to stiffness matrix
        I(loc) = set_Rows(idx,3);
        J(loc) = set_Cols(idx,3);
        A(loc) = Aloc(:);
        loc = loc+9;

      end

    % Assign output arguments
    if(nargout > 1)
        varargout{1} = I;
        varargout{2} = J;
        varargout{3} = A;
    else
        varargout{1} = sparse(I,J,A);
    end

return
